==> qmmp-1.3.4-1.src.tar.gz: qmmp-1.3.4/src/app/translations/qmmp_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>BuiltinCommandLineOption</name>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="71"/>
        <source>Don&apos;t clear the playlist</source>
        <translation>Не очищать лист</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="72"/>
        <source>Start playing current song</source>
        <translation>Воспроизвести текущую песню</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="73"/>
        <source>Pause current song</source>
        <translation>Приостановить текущую песню</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="74"/>
        <source>Pause if playing, play otherwise</source>
        <translation>Приостановить/воспроизвести</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="75"/>
        <source>Stop current song</source>
        <translation>Остановить текущую песню</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="76"/>
        <source>Display Jump to File dialog</source>
        <translation>Показать диалог перехода к файлу</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="77"/>
        <source>Quit application</source>
        <translation>Завершить приложение</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="78"/>
        <source>Set playback volume (example: qmmp --volume 20)</source>
        <translation>Установить громкость (пример: qmmp --volume 20)</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="79"/>
        <source>Print volume level</source>
        <translation>Вывести уровень громкости</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="80"/>
        <source>Mute/Restore volume</source>
        <translation>Приглушить/Восстановить громкость</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="81"/>
        <source>Print mute status</source>
        <translation>Проверить, приглушен ли звук</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="82"/>
        <source>Skip forward in playlist</source>
        <translation>Перейти к следующему фрагменту</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="83"/>
        <source>Skip backwards in playlist</source>
        <translation>Перейти к предыдущему фрагменту</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="84"/>
        <source>Show/hide application</source>
        <translation>Показать/скрыть приложение</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="85"/>
        <source>Show main window</source>
        <translation>Показать главное окно</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="86"/>
        <source>Display Add File dialog</source>
        <translation>Показать диалог добавления файлов</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="87"/>
        <source>Display Add Directory dialog</source>
        <translation>Показать диалог добавления директорий</translation>
    </message>
</context>
<context>
    <name>QMMPStarter</name>
    <message>
        <location filename="../qmmpstarter.cpp" line="113"/>
        <source>Unknown command</source>
        <translation>Неизвестная команда</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="413"/>
        <source>Usage: qmmp [options] [files]</source>
        <translation>Использование: qmmp [options] [files]</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="414"/>
        <source>Options:</source>
        <translation>Опции:</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="420"/>
        <source>Start qmmp with the specified user interface</source>
        <translation>Запустить qmmp с указанным интерфейсом пользователя</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="421"/>
        <source>List all available user interfaces</source>
        <translation>Вывести доступные интерфейсы пользователя</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="422"/>
        <source>Don&apos;t start the application</source>
        <translation>Не запускать приложение</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="423"/>
        <source>Display this text and exit</source>
        <translation>Показать этот текст и выйти</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="424"/>
        <source>Print version number and exit</source>
        <translation>Показать версии и выйти</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="426"/>
        <source>Home page: %1</source>
        <translation>Домашняя страница: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="427"/>
        <source>Development page: %1</source>
        <translation>Страница разработки: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="428"/>
        <source>Bug tracker: %1</source>
        <translation>Система регистрации ошибок: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="135"/>
        <location filename="../qmmpstarter.cpp" line="433"/>
        <source>Command Line Help</source>
        <translation>Справка по командной строке</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="446"/>
        <source>QMMP version: %1</source>
        <translation>Версия QMMP: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="447"/>
        <source>Compiled with Qt version: %1</source>
        <translation>Собрано с версией Qt: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="448"/>
        <source>Using Qt version: %1</source>
        <translation>Используемая версия Qt: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="451"/>
        <source>Qmmp Version</source>
        <translation>Версия Qmmp</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="468"/>
        <source>User Interfaces</source>
        <translation>Интерфейсы пользователя</translation>
    </message>
</context>
</TS>

==> qmmp-2.1.2-1.src.tar.gz: qmmp-2.1.2/src/app/translations/qmmp_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>BuiltinCommandLineOption</name>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="71"/>
        <source>Don&apos;t clear the playlist</source>
        <translation>Не очищать лист</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="72"/>
        <source>Start playing current song</source>
        <translation>Воспроизвести текущую песню</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="73"/>
        <source>Pause current song</source>
        <translation>Приостановить текущую песню</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="74"/>
        <source>Pause if playing, play otherwise</source>
        <translation>Приостановить/воспроизвести</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="75"/>
        <source>Stop current song</source>
        <translation>Остановить текущую песню</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="76"/>
        <source>Display Jump to File dialog</source>
        <translation>Показать диалог перехода к файлу</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="77"/>
        <source>Quit application</source>
        <translation>Завершить приложение</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="78"/>
        <source>Set playback volume (example: qmmp --volume 20)</source>
        <translation>Установить громкость (пример: qmmp --volume 20)</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="79"/>
        <source>Print volume level</source>
        <translation>Вывести уровень громкости</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="80"/>
        <source>Mute/Restore volume</source>
        <translation>Приглушить/Восстановить громкость</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="81"/>
        <source>Print mute status</source>
        <translation>Проверить, приглушен ли звук</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="82"/>
        <source>Skip forward in playlist</source>
        <translation>Перейти к следующему фрагменту</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="83"/>
        <source>Skip backwards in playlist</source>
        <translation>Перейти к предыдущему фрагменту</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="84"/>
        <source>Show/hide application</source>
        <translation>Показать/скрыть приложение</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="85"/>
        <source>Show main window</source>
        <translation>Показать главное окно</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="86"/>
        <source>Display Add File dialog</source>
        <translation>Показать диалог добавления файлов</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="87"/>
        <source>Display Add Directory dialog</source>
        <translation>Показать диалог добавления каталогов</translation>
    </message>
</context>
<context>
    <name>QMMPStarter</name>
    <message>
        <location filename="../qmmpstarter.cpp" line="121"/>
        <source>Unknown command</source>
        <translation>Неизвестная команда</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="438"/>
        <source>Usage: qmmp [options] [files]</source>
        <translation>Использование: qmmp [options] [files]</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="439"/>
        <source>Options:</source>
        <translation>Опции:</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="445"/>
        <source>Start qmmp with the specified user interface</source>
        <translation>Запустить qmmp с указанным интерфейсом пользователя</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="446"/>
        <source>List all available user interfaces</source>
        <translation>Вывести доступные интерфейсы пользователя</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="447"/>
        <source>Don&apos;t start the application</source>
        <translation>Не запускать приложение</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="448"/>
        <source>Display this text and exit</source>
        <translation>Показать этот текст и выйти</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="449"/>
        <source>Print version number and exit</source>
        <translation>Показать версии и выйти</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="451"/>
        <source>Home page: %1</source>
        <translation>Домашняя страница: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="452"/>
        <source>Development page: %1</source>
        <translation>Страница разработки: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="453"/>
        <source>Bug tracker: %1</source>
        <translation>Система регистрации ошибок: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="143"/>
        <location filename="../qmmpstarter.cpp" line="458"/>
        <source>Command Line Help</source>
        <translation>Справка по командной строке</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="471"/>
        <source>QMMP version: %1</source>
        <translation>Версия QMMP: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="472"/>
        <source>Compiled with Qt version: %1</source>
        <translation>Собрано с версией Qt: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="473"/>
        <source>Using Qt version: %1</source>
        <translation>Используемая версия Qt: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="476"/>
        <source>Qmmp Version</source>
        <translation>Версия Qmmp</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="493"/>
        <source>User Interfaces</source>
        <translation>Интерфейсы пользователя</translation>
    </message>
</context>
</TS>
